@@ -664,14 +664,29 @@ theme_message_area_update (AppearanceData *data)
     data->theme_message_label = gtk_label_new (NULL);
     gtk_widget_show (data->theme_message_label);
     gtk_label_set_line_wrap (GTK_LABEL (data->theme_message_label), TRUE);
+#if GTK_CHECK_VERSION (3, 16, 0)
+	gtk_label_set_xalign (GTK_LABEL (data->theme_message_label), 0.0);
+#else
     gtk_misc_set_alignment (GTK_MISC (data->theme_message_label), 0.0, 0.5);
+#endif
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+    hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 9);
+#else
     hbox = gtk_hbox_new (FALSE, 9);
+#endif
     gtk_widget_show (hbox);
-    data->theme_info_icon = gtk_image_new_from_stock (GTK_STOCK_DIALOG_INFO, GTK_ICON_SIZE_DIALOG);
-    data->theme_error_icon = gtk_image_new_from_stock (GTK_STOCK_DIALOG_WARNING, GTK_ICON_SIZE_DIALOG);
-    gtk_misc_set_alignment (GTK_MISC (data->theme_info_icon), 0.5, 0);
-    gtk_misc_set_alignment (GTK_MISC (data->theme_error_icon), 0.5, 0);
+    data->theme_info_icon = gtk_image_new_from_icon_name ("dialog-information", GTK_ICON_SIZE_DIALOG);
+    data->theme_error_icon = gtk_image_new_from_icon_name ("dialog-warning", GTK_ICON_SIZE_DIALOG);
+#if GTK_CHECK_VERSION (3, 0, 0)
+    gtk_widget_set_halign (data->theme_info_icon, GTK_ALIGN_CENTER);
+    gtk_widget_set_valign (data->theme_info_icon, GTK_ALIGN_START);
+    gtk_widget_set_halign (data->theme_error_icon, GTK_ALIGN_CENTER);
+    gtk_widget_set_valign (data->theme_error_icon, GTK_ALIGN_START);
+#else
+    gtk_misc_set_alignment (GTK_MISC (data->theme_info_icon), 0.5, 0.0);
+    gtk_misc_set_alignment (GTK_MISC (data->theme_error_icon), 0.5, 0.0);
+#endif
     gtk_box_pack_start (GTK_BOX (hbox), data->theme_info_icon, FALSE, FALSE, 0);
     gtk_box_pack_start (GTK_BOX (hbox), data->theme_error_icon, FALSE, FALSE, 0);
     gtk_box_pack_start (GTK_BOX (hbox), data->theme_message_label, TRUE, TRUE, 0);
@@ -1075,12 +1090,12 @@ void themes_init(AppearanceData* data)
 
   w = appearance_capplet_get_widget (data, "theme_install");
   gtk_button_set_image (GTK_BUTTON (w),
-                        gtk_image_new_from_stock (GTK_STOCK_OPEN, GTK_ICON_SIZE_BUTTON));
+                        gtk_image_new_from_icon_name ("document-open", GTK_ICON_SIZE_BUTTON));
   g_signal_connect (w, "clicked", (GCallback) theme_install_cb, data);
 
   w = appearance_capplet_get_widget (data, "theme_save");
   gtk_button_set_image (GTK_BUTTON (w),
-                        gtk_image_new_from_stock (GTK_STOCK_SAVE_AS, GTK_ICON_SIZE_BUTTON));
+                        gtk_image_new_from_icon_name ("document-save-as", GTK_ICON_SIZE_BUTTON));
   g_signal_connect (w, "clicked", (GCallback) theme_save_cb, data);
 
   w = appearance_capplet_get_widget (data, "theme_custom");
