@@ -31,10 +31,13 @@
 #include "mate-utils.h"
 #include "libslab-utils.h"
 
-#define MATECONF_SEND_TO_CMD_KEY       "/desktop/mate/applications/main-menu/file-area/file_send_to_cmd"
-#define MATECONF_ENABLE_DELETE_KEY_DIR "/apps/caja/preferences"
-#define MATECONF_ENABLE_DELETE_KEY     MATECONF_ENABLE_DELETE_KEY_DIR "/enable_delete"
-#define MATECONF_CONFIRM_DELETE_KEY    MATECONF_ENABLE_DELETE_KEY_DIR "/confirm_trash"
+#define GNOME_MAIN_MENU_SCHEMA         "org.mate.gnome-main-menu.file-area"
+#define SETTINGS_FILE_MGR_OPEN_KEY     "file-mgr-open-cmd"
+#define SETTINGS_SEND_TO_CMD_KEY       "file-send-to-cmd"
+
+#define CAJA_SCHEMA                    "org.mate.caja.preferences"
+#define SETTINGS_ENABLE_DELETE_KEY     "enable-delete"
+#define SETTINGS_CONFIRM_DELETE_KEY    "confirm-trash"
 
 G_DEFINE_TYPE (DirectoryTile, directory_tile, NAMEPLATE_TILE_TYPE)
 
@@ -56,7 +59,7 @@ static void send_to_trigger (Tile *, TileEvent *, TileAction *);
 
 static void rename_entry_activate_cb (GtkEntry *, gpointer);
 static gboolean rename_entry_key_release_cb (GtkWidget *, GdkEventKey *, gpointer);
-static void mateconf_enable_delete_cb (MateConfClient *, guint, MateConfEntry *, gpointer);
+static void settings_enable_delete_cb (GSettings *, gchar *, gpointer);
 
 static void disown_spawned_child (gpointer);
 
@@ -72,7 +75,9 @@ typedef struct
 	gboolean image_is_broken;
 	
 	gboolean delete_enabled;
-	guint mateconf_conn_id;
+	
+	GSettings *caja_settings;
+	GSettings *gnome_main_menu_settings;
 } DirectoryTilePrivate;
 
 #define DIRECTORY_TILE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), DIRECTORY_TILE_TYPE, DirectoryTilePrivate))
@@ -259,23 +264,19 @@ static void
 directory_tile_private_setup (DirectoryTile *tile)
 {
 	DirectoryTilePrivate *priv = DIRECTORY_TILE_GET_PRIVATE (tile);
-	MateConfClient *client;
 
 	if (priv->mime_type)
 		priv->default_app = g_app_info_get_default_for_type (priv->mime_type, TRUE);
 	else
 		priv->default_app = NULL;
 
-	priv->delete_enabled =
-		(gboolean) GPOINTER_TO_INT (get_mateconf_value (MATECONF_ENABLE_DELETE_KEY));
+	priv->gnome_main_menu_settings = g_settings_new (GNOME_MAIN_MENU_SCHEMA);
+	priv->caja_settings = g_settings_new (CAJA_SCHEMA);
 
-	client = mateconf_client_get_default ();
+	priv->delete_enabled = g_settings_get_boolean (priv->caja_settings, SETTINGS_ENABLE_DELETE_KEY);
 
-	mateconf_client_add_dir (client, MATECONF_ENABLE_DELETE_KEY_DIR, MATECONF_CLIENT_PRELOAD_NONE, NULL);
-	priv->mateconf_conn_id =
-		connect_mateconf_notify (MATECONF_ENABLE_DELETE_KEY, mateconf_enable_delete_cb, tile);
-
-	g_object_unref (client);
+	g_signal_connect (priv->caja_settings, "changed::" SETTINGS_ENABLE_DELETE_KEY,
+		G_CALLBACK (settings_enable_delete_cb), tile);
 }
 
 static void
@@ -290,7 +291,8 @@ directory_tile_init (DirectoryTile *tile)
 	priv->mime_type = NULL;
 	priv->image_is_broken = TRUE;
 	priv->delete_enabled = FALSE;
-	priv->mateconf_conn_id = 0;
+	priv->gnome_main_menu_settings = NULL;
+	priv->caja_settings = NULL;
 }
 
 static void
@@ -298,21 +300,15 @@ directory_tile_finalize (GObject *g_object)
 {
 	DirectoryTilePrivate *priv = DIRECTORY_TILE_GET_PRIVATE (g_object);
 
-	MateConfClient *client;
-
 	g_free (priv->basename);
 	g_free (priv->icon_name);
 	g_free (priv->mime_type);
 
 	if (priv->default_app)
 		g_object_unref (priv->default_app);
-    
-	client = mateconf_client_get_default ();
 
-	mateconf_client_notify_remove (client, priv->mateconf_conn_id);
-	mateconf_client_remove_dir (client, MATECONF_ENABLE_DELETE_KEY_DIR, NULL);
-
-	g_object_unref (client);
+	g_object_unref (priv->gnome_main_menu_settings);
+	g_object_unref (priv->caja_settings);
 
 	(* G_OBJECT_CLASS (directory_tile_parent_class)->finalize) (g_object);
 }
@@ -346,7 +342,11 @@ create_header (const gchar *name)
 
 	header = gtk_label_new (name);
 	gtk_label_set_ellipsize (GTK_LABEL (header), PANGO_ELLIPSIZE_END);
+#if GTK_CHECK_VERSION (3, 16, 0)
+	gtk_label_set_xalign (GTK_LABEL (header), 0.0);
+#else
 	gtk_misc_set_alignment (GTK_MISC (header), 0.0, 0.5);
+#endif
 
 	header_bin = gtk_alignment_new (0.0, 0.5, 1.0, 0.0);
 	gtk_container_add (GTK_CONTAINER (header_bin), header);
@@ -413,7 +413,11 @@ rename_entry_activate_cb (GtkEntry *entry, gpointer user_data)
 	g_object_unref (dst_file);
 
 	header = gtk_label_new (priv->basename);
+#if GTK_CHECK_VERSION (3, 16, 0)
+	gtk_label_set_xalign (GTK_LABEL (header), 0.0);
+#else
 	gtk_misc_set_alignment (GTK_MISC (header), 0.0, 0.5);
+#endif
 
 	child = gtk_bin_get_child (priv->header_bin);
 
@@ -432,7 +436,7 @@ rename_entry_key_release_cb (GtkWidget *widget, GdkEventKey *event, gpointer use
 }
 
 static void
-mateconf_enable_delete_cb (MateConfClient *client, guint conn_id, MateConfEntry *entry, gpointer user_data)
+settings_enable_delete_cb (GSettings *settings, gchar *key, gpointer user_data)
 {
 	Tile *tile = TILE (user_data);
 	DirectoryTilePrivate *priv = DIRECTORY_TILE_GET_PRIVATE (user_data);
@@ -445,7 +449,7 @@ mateconf_enable_delete_cb (MateConfClient *client, guint conn_id, MateConfEntry
 
 	menu = GTK_MENU_SHELL (tile->context_menu);
 
-	delete_enabled = mateconf_value_get_bool (entry->value);
+	delete_enabled = g_settings_get_boolean (settings, key);
 
 	if (delete_enabled == priv->delete_enabled)
 		return;
@@ -521,6 +525,7 @@ move_to_trash_trigger (Tile *tile, TileEvent *event, TileAction *action)
 static void
 delete_trigger (Tile *tile, TileEvent *event, TileAction *action)
 {
+	DirectoryTilePrivate *priv = DIRECTORY_TILE_GET_PRIVATE (tile);
 	GtkDialog *confirm_dialog;
 	gint       result;
 
@@ -528,7 +533,7 @@ delete_trigger (Tile *tile, TileEvent *event, TileAction *action)
 	gboolean res;
 	GError *error = NULL;
 
-	if (GPOINTER_TO_INT (libslab_get_mateconf_value (MATECONF_CONFIRM_DELETE_KEY))) {
+	if (g_settings_get_boolean (priv->caja_settings, SETTINGS_CONFIRM_DELETE_KEY)) {
 		confirm_dialog = GTK_DIALOG(gtk_message_dialog_new (NULL, 0, GTK_MESSAGE_WARNING, 
 				GTK_BUTTONS_NONE, _("Are you sure you want to permanently delete \"%s\"?"), DIRECTORY_TILE_GET_PRIVATE (tile)->basename));
 		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG(confirm_dialog), _("If you delete an item, it is permanently lost."));
@@ -561,6 +566,7 @@ delete_trigger (Tile *tile, TileEvent *event, TileAction *action)
 static void
 send_to_trigger (Tile *tile, TileEvent *event, TileAction *action)
 {
+	DirectoryTilePrivate *priv = DIRECTORY_TILE_GET_PRIVATE (tile);
 	gchar  *cmd;
 	gint    argc;
 	gchar **argv_parsed = NULL;
@@ -575,7 +581,7 @@ send_to_trigger (Tile *tile, TileEvent *event, TileAction *action)
 	gint i;
 
 
-	cmd = (gchar *) get_mateconf_value (MATECONF_SEND_TO_CMD_KEY);
+	cmd = g_settings_get_string (priv->gnome_main_menu_settings, SETTINGS_SEND_TO_CMD_KEY);
 
 	if (! g_shell_parse_argv (cmd, & argc, & argv_parsed, NULL))
 		goto exit;
@@ -662,7 +668,7 @@ open_with_default_trigger (Tile *tile, TileEvent *event, TileAction *action)
 	} else {
 		gchar *cmd;
 		cmd = string_replace_once (
-			get_slab_mateconf_string (SLAB_FILE_MANAGER_OPEN_CMD), "FILE_URI", tile->uri);
+			g_settings_get_string (priv->gnome_main_menu_settings, SETTINGS_FILE_MGR_OPEN_KEY), "FILE_URI", tile->uri);
 		spawn_process (cmd);
 		g_free (cmd);
 	}
