@@ -92,10 +92,10 @@ static guint signals[LAST_SIGNAL] = { 0 };
 static void
 drw_break_window_class_init (DrwBreakWindowClass *klass)
 {
-        GObjectClass *object_class = G_OBJECT_CLASS (klass);
+	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-        object_class->finalize = drw_break_window_finalize;
-        object_class->dispose = drw_break_window_dispose;
+	object_class->finalize = drw_break_window_finalize;
+	object_class->dispose = drw_break_window_dispose;
 
 	signals[POSTPONE] =
 		g_signal_new ("postpone",
@@ -167,7 +167,11 @@ drw_break_window_init (DrwBreakWindow *window)
 	align = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
 	gtk_widget_show (align);
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+	outer_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
+#else
 	outer_vbox = gtk_vbox_new (FALSE, 0);
+#endif
 	gtk_widget_show (outer_vbox);
 
 	right_padding = gdk_screen_get_width (screen) - monitor.width - monitor.x;
@@ -187,7 +191,11 @@ drw_break_window_init (DrwBreakWindow *window)
 	gtk_box_pack_start (GTK_BOX (outer_vbox), align, TRUE, TRUE, 0);
 
 	if (allow_postpone) {
+#if GTK_CHECK_VERSION (3, 0, 0)
+		button_box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+#else
 		button_box = gtk_hbox_new (FALSE, 0);
+#endif
 		gtk_widget_show (button_box);
 
 		gtk_container_set_border_width (GTK_CONTAINER (button_box), 12);
@@ -220,17 +228,30 @@ drw_break_window_init (DrwBreakWindow *window)
 		gtk_box_pack_end (GTK_BOX (outer_vbox), button_box, FALSE, TRUE, 0);
 	}
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
+#else
 	vbox = gtk_vbox_new (FALSE, 0);
+#endif
 	gtk_widget_show (vbox);
 
 	gtk_container_add (GTK_CONTAINER (align), vbox);
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+#else
 	hbox = gtk_hbox_new (FALSE, 0);
+#endif
 	gtk_widget_show (hbox);
 	gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, FALSE, 0);
 
-	priv->image = gtk_image_new_from_stock (GTK_STOCK_STOP, GTK_ICON_SIZE_DIALOG);
-	gtk_misc_set_alignment (GTK_MISC (priv->image), 1, 0.5);
+	priv->image = gtk_image_new_from_icon_name ("process-stop", GTK_ICON_SIZE_DIALOG);
+#if GTK_CHECK_VERSION (3, 0, 0)
+	gtk_widget_set_halign (priv->image, GTK_ALIGN_END);
+	gtk_widget_set_valign (priv->image, GTK_ALIGN_CENTER);
+#else
+	gtk_misc_set_alignment (GTK_MISC (priv->image), 1.0, 0.5);
+#endif
 	gtk_widget_show (priv->image);
 	gtk_box_pack_start (GTK_BOX (hbox), priv->image, TRUE, TRUE, 8);
 
@@ -261,7 +282,6 @@ drw_break_window_init (DrwBreakWindow *window)
 
 
 	priv->clock_label = gtk_label_new (NULL);
-	gtk_misc_set_alignment (GTK_MISC (priv->clock_label), 0.5, 0.5);
 	gtk_widget_show (priv->clock_label);
 	gtk_box_pack_start (GTK_BOX (vbox), priv->clock_label, TRUE, TRUE, 8);
 
@@ -319,7 +339,7 @@ drw_break_window_finalize (GObject *object)
 
 	if (G_OBJECT_CLASS (drw_break_window_parent_class)->finalize) {
 		(* G_OBJECT_CLASS (drw_break_window_parent_class)->finalize) (object);
-        }
+	}
 }
 
 static void
@@ -590,65 +610,25 @@ get_layout_location (GtkLabel *label,
 	}
 }
 
-static gboolean
 #if GTK_CHECK_VERSION (3, 0, 0)
-label_draw_event_cb   (GtkLabel       *label,
-		       cairo_t        *cr,
-#else
-label_expose_event_cb (GtkLabel       *label,
-		       GdkEventExpose *event,
-#endif
-		       gpointer        user_data)
+static gboolean
+label_draw_event_cb (GtkLabel *label,
+                     cairo_t  *cr,
+                     gpointer  user_data)
 {
 	gint       x, y;
-	GdkColor   color;
 	GtkWidget *widget;
-	GdkWindow *window;
-#if !GTK_CHECK_VERSION (3, 0, 0)
-	cairo_t *cr;
-#endif
-
-	color.red = 0;
-	color.green = 0;
-	color.blue = 0;
-	color.pixel = 0;
 
 	get_layout_location (label, &x, &y);
 
 	widget = GTK_WIDGET (label);
-	window = gtk_widget_get_window (widget);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	pango_cairo_show_layout (cr, gtk_label_get_layout (label));
-#else
-	cr = gdk_cairo_create (window);
-
-        gdk_cairo_rectangle (cr, &event->area);
-        cairo_clip (cr);
-
-        cairo_set_source_rgb (cr, 0, 0, 0);
-
-        /* Can't use pango_cairo_show_layout() here as we need to override
-         * the layout's colors with our shadow color.
-         */
-        cairo_move_to (cr, x + 1, y + 1);
-        pango_cairo_layout_path (cr, gtk_label_get_layout (label));
-        cairo_fill (cr);
-
-        cairo_destroy (cr);
-#endif
 
 	gtk_paint_layout (gtk_widget_get_style (widget),
-#if GTK_CHECK_VERSION (3, 0, 0)
 			  cr,
-#else
-			  window,
-#endif
 			  gtk_widget_get_state (widget),
 			  FALSE,
-#if !GTK_CHECK_VERSION (3, 0, 0)
-			  &event->area,
-#endif
 			  widget,
 			  "label",
 			  x, y,
@@ -656,6 +636,48 @@ label_expose_event_cb (GtkLabel       *label,
 
 	return TRUE;
 }
+#else
+static gboolean
+label_expose_event_cb (GtkLabel       *label,
+                       GdkEventExpose *event,
+                       gpointer        user_data)
+{
+	gint       x, y;
+	GtkWidget *widget;
+	GdkWindow *window;
+	cairo_t *cr;
+
+	get_layout_location (label, &x, &y);
+
+	widget = GTK_WIDGET (label);
+	window = gtk_widget_get_window (widget);
+
+	cr = gdk_cairo_create (window);
+
+	gdk_cairo_rectangle (cr, &event->area);
+	cairo_clip (cr);
+
+	cairo_set_source_rgb (cr, 0, 0, 0);
+
+	cairo_move_to (cr, x + 1, y + 1);
+	pango_cairo_layout_path (cr, gtk_label_get_layout (label));
+	cairo_fill (cr);
+
+	cairo_destroy (cr);
+
+	gtk_paint_layout (gtk_widget_get_style (widget),
+			  window,
+			  gtk_widget_get_state (widget),
+			  FALSE,
+			  &event->area,
+			  widget,
+			  "label",
+			  x, y,
+			  gtk_label_get_layout (label));
+
+	return TRUE;
+}
+#endif
 
 static void
 label_size_request_cb (GtkLabel       *label,
